# !/usr/bin/env python
#  -*- coding: UTF-8 -*-

__version__ = "0.2"  # LATEST? =>  https://pypi.org/project/lookml-helper/
__copyright__ = "CopyRight (C) 2022 by Michele Pasin and Joerg Sixt"
__license__ = "MIT"
__author__ = "Michele Pasin and Joerg Sixt"
__author_email__ = ""

USAGE = "lookmlhelper [options]"
VERSION = "v" + __version__
AGENT = "%s/%s" % (__name__, __version__)
